       program delete_reflections
c
********************************************************************************
*                                                                              *
*            Author : J.Jansen                    Date: 29 January 1987        *
*    Revision : 1.0          Author : J.Jansen         Date : 27 July 1989     *
*    Revision : 1.1          Author : J.Jansen         Date : 6 September 1989 *
*    Revision : 1.2          Author : J.Jansen         Date : 7 November 1989  *
*    Revision : 1.3          Author : J.Jansen         Date : 2 January 1990   *
*                                                                              *
*------------------------------------------------------------------------------*
*                                                                              *
* Program to remove "less thans" and equivalent reflections from a hkli file   *
* and systematic extinctions                                                   *
*                                                                              *
*------------------------------------------------------------------------------*
*                                                                              *
*     Variable          Type                  Purpose                          *
*     paraf            char*38        Parameter file                           *
*     listf            char*38        Listing file                             *
*     ili              integer        Logical unit number listing file         *
*     ipf              integer        Logical unit number parmeter file        *
*     dat              char*9         Date                                     *
*     tim              char*8         Time                                     *
*     hklif            char*38        Hkli file                                *
*     count            real           Intensity                                *
*     ercount          real           Error in intensity                       *
*     comment          char*41        Comment string for parameter file        *
*     ermult           real           Error multiplication factor              *
*     icount           integer        Do-loop parameter                        *
*     terminal_name    char*7         Terminal name                            *
*     master_pid       integer        Master pid number                        *
*     len_page         integer        Terminal page length                     *
*     groupno          integer        Space group number                       *
*     setting          integer        Space group setting                      *
*     npk_help         integer        Number of reflections                    *
*     loopend          integer        End of a do-loop                         *
*     cond             logical        Delete condition                         *
*     ang_max          real           Maximal 2-theta                          *
*                                                                              *
*------------------------------------------------------------------------------*
*                                                                              *
*     Calls subroutines : openpf                                               *
*                         getchr                                               *
*                         getrea                                               *
*                         putchr                                               *
*                         opendat                                              *
*                         getuh                                                *
*                         read_hklif                                           *
*                         write_hklif                                          *
*                         putuh                                                *
*                         reply_oper9                                          *
*                         getint                                               *
*                         sort_hkli                                            *
*                         delref_remove_extinctions                            *
*                                                                              *
********************************************************************************
c
      include '($dvidef)/list'
c
      include '($jpidef)/list'
c
      include '$disk2:[joukj.powder.source]common_uhdi.inc/list'
c
      include '$disk2:[joukj.powder.source]common_geind.inc/list'
c
      character*41 comment
      character*38 paraf , listf , hklif
      character*9 dat
      character*8 tim
      character*7 terminal_name
      integer groupno , setting
      logical cond
c
c Get parameter file
      paraf = 'dgs.pf'
      ipf = 1
      call openpf( ipf , paraf )
c
c Get listing file and write header
      listf = '@CONSOLE'
      call getchr( ipf , 'LIST' , 'Listing file' , listf , 38 )
      if ( listf .eq. '@CONSOLE' ) then
        ili = 6
        write( ili , '( 1x , a1 , ''[2J'' , a1 , ''[1;1f'' )' ) 27 , 27
        write( ili , '( 1x , a1 , ''#5'' , a1 , ''#3'' ,
     >         ''       '' , a1 , ''[5mDELETE_REFLECTIONS'' , a1 ,
     >           ''[0m'' )' ) 27 , 27 , 27 , 27
        write( ili , '( 1x , a1 , ''#5'' , a1 , ''#4'' ,
     >         ''       '' , a1 , ''[5mDELETE_REFLECTIONS'' , a1 ,
     >           ''[0m'' )' ) 27 , 27 , 27 , 27
        call lib$getjpi( jpi$_master_pid , , , master_pid )
        call lib$getjpi( jpi$_terminal , master_pid , , , terminal_name
     >           )
        call lib$getdvi( dvi$_tt_page , , terminal_name , len_page , , )
        write( ili , '( 1x , a1 , ''[5;'' , i2 , ''r'' , a1 , ''[?6h''
     >            )' ) 27 , len_page , 27
      else
        ili = 2
        open( unit=ili , file=listf , status='unknown' , access='append'
     >           )
      end if
      call date( dat )
      call time( tim )
      write( ili , '( '' delete_reflections ; date : '' , a9 ,
     >          '' ; time : '' , a8 )' ) dat , tim
c
c Get old hkli file
      hklif = 'delete.ri'
      call getchr( ipf , 'HKLIF' , 'Hkli file' , hklif , 38 )
      call opendat( 3 , hklif , 'old' )
c
c Get data
      call getuh( 3 , 'II' )
      call read_hklif( 3 )
c
c Get multiplication factor for error
      ermult = 1.0
      call getrea( ipf , 'ERMULT' , 'Multiplication factor for error' ,
     >             ermult )
c
c Get maximal 2-theta
      ang_max = 180.0
      call getrea( ipf , 'MAX2T' , 'Maximal 2-theta' , ang_max )
c
c Delete reflections
      loopend = npk
      npk = 0
      do icount = 1 , loopend
        if ( ( count( icount ) .gt. ermult * ercount( icount ) ) .and. (
     >    theta2( icount ) .le. ang_max ) ) then
          npk = npk + 1
          ih( npk ) = ih( icount )
          ik( npk ) = ik( icount )
          il( npk ) = il( icount )
          theta2( npk ) = theta2( icount )
          count( npk ) = count( icount )
          ercount( npk ) = ercount( icount )
        end if
      end do
c
c Get space groupnumber
      groupno = 1
      setting = 1
      call getint( ipf , 'GROUPNO' , 'Space group number' , groupno )
      call getint( ipf , 'SETTING' , 'Space group setting' , setting )
c
c Remove systematic extinctions
      call delref_remove_extinctions( groupno , setting , ili )
c
c Sort hkli list
      npk_help = npk
      call sort_hkli( npk )
c
c Remove equivalent reflections
      loopend = npk
      npk = 1
      do icount = 2 , loopend
        jcount = 0
57      if ( theta2( icount ) - theta2( npk - jcount ) .lt. .0027 ) then
          if ( groupno .ge. 1 .and. groupno .le. 2 ) then
            cond = ( ih( icount ) .ne. -ih( npk - jcount ) .or. ik(
     >        icount ) .ne. -ik( npk - jcount ) .or. il( icount ) .ne.
     >        -il( npk - jcount ) )
          else if ( groupno .ge. 3 .and. groupno .le. 15 .and. setting
     >      .ge. 2 ) then
            cond = ( ih( icount ) .ne. -ih( npk - jcount ) .or. il(
     >        icount ) .ne. -il( npk - jcount ) .or. ik( icount ) .ne.
     >        abs( ik( npk - jcount ) ) ) .and. ( ih( icount ) .ne. ih(
     >        npk - jcount ) .or. il( icount ) .ne. il( npk - jcount )
     >        .or. ik( icount ) .ne. -ik( npk - jcount ) )
          else if ( groupno .ge. 16 .and. groupno .le. 74 ) then
            cond = ( abs( ih( icount ) ) .ne. abs( ih( npk - jcount ) )
     >        .or. abs( ik( icount ) ) .ne. abs( ik( npk - jcount ) )
     >        .or. abs( il( icount ) ) .ne. abs( il( npk - jcount ) ) )
          else if ( groupno .ge. 75 .and. groupno .le. 148 ) then
            cond = ( abs( ih( icount ) ) .ne. abs( ih( npk - jcount ) )
     >        .or. abs( ik( icount ) ) .ne. abs( ik( npk - jcount ) )
     >        .or. abs( il( icount ) ) .ne. abs( il( npk - jcount ) ) )
            cond = ( cond .and. ( ( ih( icount ) .ne. 0 ) .or. ( 0 .ne.
     >        ik( npk - jcount ) ) .or. ( ik( icount ) .ne. ih( npk -
     >        jcount ) ) .or. ( il( icount ) .ne. il( npk - jcount ) )
     >        ) )
            cond = ( cond .and. ( ( ik( icount ) .ne. 0 ) .or. ( 0 .ne.
     >        ih( npk - jcount ) ) .or. ( ih( icount ) .ne. ik( npk -
     >        jcount ) ) .or. ( il( icount ) .ne. il( npk - jcount ) )
     >        ) )
          else if ( groupno .ge. 149 .and. groupno .le. 167 ) then
            cond = ( ( ih( icount ) .ne. -ih( npk - jcount ) ) .or. (
     >        ik( icount ) .ne. -ik( npk - jcount ) ) .or. ( il( icount
     >        ) .ne. -il( npk - jcount ) ) )
            cond = ( cond .and. ( ( ih( icount ) .ne. ik( npk - jcount )
     >        ) .or. ( ik( icount ) .ne. -( ih( npk - jcount ) + ik( npk
     >        - jcount ) ) ) .or. ( il( icount ) .ne. il( npk - jcount )
     >         ) ) )
            cond = ( cond .and. ( ( ih( icount ) .ne. -ik( npk - jcount
     >        ) ) .or. ( ik( icount ) .ne. ( ih( npk - jcount ) + ik(
     >        npk - jcount ) ) ) .or. ( il( icount ) .ne. -il( npk -
     >        jcount ) ) ) )
            cond = ( cond .and. ( ( ih( icount ) .ne. -ik( npk - jcount
     >        ) ) .or. ( ik( icount ) .ne. -ih( npk - jcount ) ) .or. (
     >        il( icount ) .ne. il( npk - jcount ) ) ) )
            cond = ( cond .and. ( ( ih( icount ) .ne. ik( npk - jcount )
     >        ) .or. ( ik( icount ) .ne. ih( npk - jcount ) ) .or. ( il(
     >        icount ) .ne. -il( npk - jcount ) ) ) )
            cond = ( cond .and. ( ( ih( icount ) .ne. ih( npk - jcount )
     >        ) .or. ( ik( icount ) .ne. -( ih( npk - jcount ) + ik( npk
     >        - jcount ) ) ) .or. ( il( icount ) .ne. -il( npk - jcount
     >        ) ) ) )
            cond = ( cond .and. ( ( ih( icount ) .ne. -ih( npk - jcount
     >        ) ) .or. ( ik( icount ) .ne. ( ih( npk - jcount ) + ik(
     >        npk - jcount ) ) ) .or. ( il( icount ) .ne. il( npk -
     >        jcount ) ) ) )
            cond = ( cond .and. ( ( ih( icount ) .ne. -( ih( npk -
     >        jcount ) + ik( npk - jcount ) ) ) .or. ( ik( icount ) .ne.
     >        ih( npk - jcount ) ) .or. ( il( icount ) .ne. il( npk -
     >        jcount ) ) ) )
            cond = ( cond .and. ( ( ih( icount ) .ne. ( ih( npk - jcount
     >        ) + ik( npk - jcount ) ) ) .or. ( ik( icount ) .ne. -ih(
     >        npk - jcount ) ) .or. ( il( icount ) .ne. -il( npk -
     >        jcount ) ) ) )
          else if ( groupno .ge. 195 .and. groupno .le. 230 ) then
            cond = ( abs( ih( icount ) ) .ne. abs( ih( npk - jcount ) )
     >        .or. abs( ik( icount ) ) .ne. abs( ik( npk - jcount ) )
     >        .or. abs( il( icount ) ) .ne. abs( il( npk - jcount ) ) )
            cond = cond .and. ( abs( ih( icount ) ) .ne. abs( ik( npk -
     >        jcount ) ) .or. abs( ik( icount ) ) .ne. abs( il( npk -
     >        jcount ) ) .or. abs( il( icount ) ) .ne. abs( ih( npk -
     >        jcount ) ) )
            cond = cond .and. ( abs( ih( icount ) ) .ne. abs( il( npk -
     >        jcount ) ) .or. abs( ik( icount ) ) .ne. abs( ih( npk -
     >        jcount ) ) .or. abs( il( icount ) ) .ne. abs( ik( npk -
     >        jcount ) ) )
            if ( groupno .ge. 207 ) then
              cond = cond .and. ( abs( ih( icount ) ) .ne. abs( ik( npk
     >          - jcount ) ) .or. abs( ik( icount ) ) .ne. abs( ih( npk
     >          - jcount ) ) .or. abs( il( icount ) ) .ne. abs( il( npk
     >          - jcount ) ) )
              cond = cond .and. ( abs( ih( icount ) ) .ne. abs( il( npk
     >          - jcount ) ) .or. abs( ik( icount ) ) .ne. abs( ik( npk
     >          - jcount ) ) .or. abs( il( icount ) ) .ne. abs( ih( npk
     >          - jcount ) ) )
              cond = cond .and. ( abs( ih( icount ) ) .ne. abs( ih( npk
     >          - jcount ) ) .or. abs( ik( icount ) ) .ne. abs( il( npk
     >          - jcount ) ) .or. abs( il( icount ) ) .ne. abs( ik( npk
     >          - jcount ) ) )
            end if
          else
            write( ili , * ) 'Space group not inplemented'
            if ( ili .eq. 6 ) then
              write( ili , '( 1x , a1 , ''[1;'' , i2 , ''r'' , a1 ,
     >          ''['' , i2 , '';1H'' )' ) 27 , len_page , 27 , len_page
            end if
            call reply_oper9(
     >        'delete_reflections space group not implemented' )
            stop 'Space group not inplemented'
          end if
          if ( cond ) then
            jcount = jcount + 1
            if ( jcount .ne. npk ) then
              goto 57
            else
              npk = npk + 1
              ih( npk ) = ih( icount )
              ik( npk ) = ik( icount )
              il( npk ) = il( icount )
              theta2( npk ) = theta2( icount )
              count( npk ) = count( icount )
              ercount( npk ) = ercount( icount )
            end if
          end if
        else
          npk = npk + 1
          ih( npk ) = ih( icount )
          ik( npk ) = ik( icount )
          il( npk ) = il( icount )
          theta2( npk ) = theta2( icount )
          count( npk ) = count( icount )
          ercount( npk ) = ercount( icount )
        end if
      end do
c
c Get new hkli file
      hklif = 'new.ri'
      call getchr( ipf , 'HKLIFNEW' , 'New hkli file' , hklif , 38 )
      call opendat( 4 , hklif , 'new' )
c
c Write data
      call write_hklif( 4 )
      call putuh( 4 )
c
c Update parameter file
      write( comment , '( ''delete_reflections ; '' , a9 , '' ; '' ,
     >           a8 )' ) dat , tim
      call putchr( ipf , 'HKLIF' , comment , hklif , 38 )
c
      if ( ili .eq. 6 ) then
        write( ili , '( 1x , a1 , ''[1;'' , i2 , ''r'' , a1 , ''['' , i2
     >           '';1H'' )' ) 27 , len_page , 27 , len_page
      end if
      call reply_oper9( 'delete_reflections normal end' )
c
      end
