[inherit('sys$library:starlet')]
{}
module delref_remove_extinctions( output );
{}
(******************************************************************************)
(*                                                                            *)
(*         Author : J.Jansen                  Date : 8 September 1989         *)
(*                                                                            *)
(*----------------------------------------------------------------------------*)
(*                                                                            *)
(* Procedure to remove space group extinctions from the reflection list       *)
(*                                                                            *)
(*----------------------------------------------------------------------------*)
(*                                                                            *)
(*     Variable            Type                  Purpose                      *)
(*     groupno           integer       Spacegroup number                      *)
(*     setting           integer       Space group setting                    *)
(*     ili               integer       Logical unit number listing file       *)
(*     terminal_name     char*7        Terminal name                          *)
(*     master_pid        integer       Master pid number                      *)
(*     len_page          integer       Terminal page length                   *)
(*     screw             byte(3)       Fold of screw axis                     *)
(*     glide             char*3        Glide planes                           *)
(*     lattice           char          Lattice type                           *)
(*     npk               integer*2     Number of peaks remaining              *)
(*     i                 integer*2     Do-loop parameter                      *)
(*     j                 byte          Do-loop parameter                      *)
(*     extinction        boolean       Is this reflection an extinction?      *)
(*     index             integer(3)    Indices of the current reflection      *)
(*     hhl               char          Hhl extinction                         *)
(*     h_hl              char          H-hl extinction                        *)
(*                                                                            *)
(*----------------------------------------------------------------------------*)
(*                                                                            *)
(*    Calls procedures : reply_oper9                                          *)
(*                       write_fortran                                        *)
(*                                                                            *)
(******************************************************************************)
{}
  [global]procedure delref_remove_extinctions( groupno , setting , ili : integer
    );
{}
    %include 'common_uhdi_pas.inc/list'
{}
    %include 'common_geind_pas.inc/list'
{}
  procedure reply_oper9( messag : [class_s]packed array[ l..u:integer]
    of char ); fortran;
  procedure write_fortran( ili : integer; messag : [class_s]packed array[
    l..u:integer ] of char ); fortran;
  procedure lib$getjpi( item : integer; var pid : integer := %immed 0;
    proc_name : [class_s]packed array[ l1..u1 : integer ] of char := %immed 0;
    var out_val : integer := %immed 0; var out_str : [class_s]packed array
    [ l2..u2 : integer ] of char := %immed 0;
    var out_len : integer := %immed 0 ); external;
  procedure lib$getdvi( item : integer; var channal : integer := %immed
    0; device_name : [class_s]packed array[ l1..u1 : integer ] of char := %immed
    0; var out_val : integer := %immed 0; var out_str : [class_s]packed array
    [ l2..u2 : integer ] of char := %immed 0;
    var out_len : integer := %immed 0 ); external;
{}
    var
      screw            : packed array[ 1..3 ] of byte;
      glide            : packed array[ 1..3 ] of char;
      terminal_name    : packed array[ 1..7 ] of char;
      h_hl,
      hhl,
      lattice          : char;
      index            : array[ 1..3 ] of integer;
      len_page,
      master_pid       : integer;
      npk,
      i                : word;
      j                : byte;
      extinction       : boolean;
{}
    begin
{}
{ Determine extinctions }
      h_hl := '0';
      hhl := '0';
      case groupno of
        1 ,
        2 ,
        3 ,
        6 ,
        10 ,
        16 ,
        25 ,
        47 ,
        75 ,
        81 ,
        83 ,
        89 ,
        99 ,
        111,
        115,
        123,
        143,
        147,
        149,
        150,
        156,
        157,
        162,
        164,
        168,
        174,
        175,
        177,
        183,
        187,
        189,
        191,
        195,
        200,
        207,
        215,
        221 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        4 ,
        11  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                case setting of
                  1 : begin
                        screw[ 2 ] := 1;
                        screw[ 3 ] := 2;
                      end;
                  2 : begin
                        screw[ 2 ] := 2;
                        screw[ 3 ] := 1;
                      end;
                  end;
                lattice := 'P';
              end;
        5 ,
        8 ,
        12  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                case setting of
                  1 : lattice := 'B';
                  2 : lattice := 'C';
                  end;
              end;
        7 ,
        13  : begin
                glide[ 1 ] := '0';
                case setting of
                  1 : begin
                        glide[ 2 ] := '0';
                        glide[ 3 ] := 'b';
                      end;
                  2 : begin
                        glide[ 2 ] := 'c';
                        glide[ 3 ] := '0';
                      end;
                  3 : begin
                        glide[ 2 ] := 'n';
                        glide[ 3 ] := '0';
                      end;
                  4 : begin
                        glide[ 2 ] := 'a';
                        glide[ 3 ] := '0';
                      end;
                  end;
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P'
              end;
        9 ,
        15  : begin
                glide[ 1 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                case setting of
                  1 : begin
                        lattice := 'B';
                        glide[ 2 ] := '0';
                        glide[ 3 ] := 'b';
                      end;
                  2 : begin
                        lattice := 'C';
                        glide[ 2 ] := 'c';
                        glide[ 3 ] := '0';
                      end;
                  end;
              end;
        14  : begin
                glide[ 1 ] := '0';
                case setting of
                  1 : begin
                        glide[ 2 ] := '0';
                        glide[ 3 ] := 'b';
                        screw[ 2 ] := 1;
                        screw[ 3 ] := 2;
                      end;
                  2 : begin
                        glide[ 2 ] := 'c';
                        glide[ 3 ] := '0';
                        screw[ 2 ] := 2;
                        screw[ 3 ] := 1;
                      end;
                  3 : begin
                        glide[ 2 ] := 'n';
                        glide[ 3 ] := '0';
                        screw[ 2 ] := 2;
                        screw[ 3 ] := 1;
                      end;
                  4 : begin
                        glide[ 2 ] := 'a';
                        glide[ 3 ] := '0';
                        screw[ 2 ] := 2;
                        screw[ 3 ] := 1;
                      end;
                  end;
                screw[ 1 ] := 1;
                lattice := 'P'
              end;
        17 ,
        77 ,
        84 ,
        93 ,
        173,
        176,
        182 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 2;
                lattice := 'P';
              end;
        18  : begin
                case setting of
                  1 : begin
                        glide[ 1 ] := '0';
                        glide[ 2 ] := '0';
                        glide[ 3 ] := '0';
                        screw[ 1 ] := 2;
                        screw[ 2 ] := 2;
                        screw[ 3 ] := 1;
                      end;
                  2 : begin
                        glide[ 1 ] := '0';
                        glide[ 2 ] := '0';
                        glide[ 3 ] := '0';
                        screw[ 1 ] := 1;
                        screw[ 2 ] := 2;
                        screw[ 3 ] := 2;
                      end;
                  otherwise
                    write_fortran( ili , ' Space group not implemented' );
                    if ili = 6 then
                      begin
                        lib$getjpi( jpi$_master_pid , , , master_pid );
                        lib$getjpi( jpi$_terminal , master_pid , , ,
                          terminal_name );
                        lib$getdvi( dvi$_tt_page , , terminal_name , len_page ,
                          , );
                        writeln(  ' ' , chr( 27 ) , '[1;' , len_page:2 , 'r' ,
                          chr( 27 ) , '[' , len_page:2 , ';1H' );
                      end;
                    reply_oper9( 'delref_rem_ext: spacegroup not implemented' );
                    halt;
                  end;
                lattice := 'P';
              end;
        19 ,
        94 ,
        198,
        208 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 2;
                screw[ 2 ] := 2;
                screw[ 3 ] := 2;
                lattice := 'P';
              end;
        20  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 2;
                lattice := 'C';
              end;
        21 ,
        35 ,
        65  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'C';
              end;
        22 ,
        42 ,
        69 ,
        196,
        202,
        209,
        216,
        225 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'F';
              end;
        23 ,
        24 ,
        44 ,
        71 ,
        79 ,
        82 ,
        87 ,
        97 ,
        107,
        119,
        121,
        139,
        197,
        199,
        204,
        211,
        217,
        229 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'I';
              end;
        26  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := 'c';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 2;
                lattice := 'P';
              end;
        27 ,
        49  : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := 'c';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 2;
                lattice := 'P';
              end;
        28  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := 'a';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        29  : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := 'a';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 2;
                lattice := 'P';
              end;
        30  : begin
                glide[ 1 ] := 'n';
                glide[ 2 ] := 'c';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 2;
                lattice := 'P';
              end;
        31  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := 'n';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 2;
                lattice := 'P';
              end;
        32 ,
        55  : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := 'a';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        33  : begin
                glide[ 1 ] := 'n';
                glide[ 2 ] := 'a';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 2;
                lattice := 'P';
              end;
        34 ,
        58  : begin
                glide[ 1 ] := 'n';
                glide[ 2 ] := 'n';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 2;
                lattice := 'P';
              end;
        36 ,
        63  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := 'c';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'C';
              end;
        37 ,
        66  : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := 'c';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'C';
              end;
        38  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'A';
              end;
        39  : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'A';
              end;
        40  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := 'a';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'A';
              end;
        41  : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := 'a';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'A';
              end;
        43  : begin
                glide[ 1 ] := 'd';
                glide[ 2 ] := 'd';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'F';
              end;
        45 ,
        72  : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := 'a';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'I';
              end;
        46  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := 'a';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'I';
              end;
        48 ,
        201,
        224  : begin
                glide[ 1 ] := 'n';
                glide[ 2 ] := 'n';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        50  : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := 'a';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        51  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        52  : begin
                glide[ 1 ] := 'n';
                glide[ 2 ] := 'n';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        53  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := 'n';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        54  : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := 'c';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        56  : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := 'c';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        57  : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := 'c';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        59 ,
        85 ,
        129 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        60  : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := 'c';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        61 ,
        205 : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := 'c';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        62  : begin
                glide[ 1 ] := 'n';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        64  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := 'c';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'C';
              end;
        67  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'C';
              end;
        68  : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := 'c';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'C';
              end;
        70 ,
        203,
        227 : begin
                glide[ 1 ] := 'd';
                glide[ 2 ] := 'd';
                glide[ 3 ] := 'd';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'F';
              end;
        73 ,
        206 : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := 'c';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'I';
              end;
        74  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'I';
              end;
        76 ,
        78 ,
        91 ,
        95  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 4;
                lattice := 'P';
              end;
        80 ,
        98  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 4;
                lattice := 'I';
              end;
        86  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 2;
                lattice := 'P';
              end;
        88  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 4;
                lattice := 'I';
              end;
        90  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 2;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        92 ,
        96  : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 2;
                screw[ 2 ] := 2;
                screw[ 3 ] := 4;
                lattice := 'P';
              end;
        100,
        117,
        127 : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        101,
        116,
        132 : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        102,
        118,
        136 : begin
                glide[ 1 ] := 'n';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        103,
        124 : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '2';
                lattice := 'P';
              end;
        104,
        128 : begin
                glide[ 1 ] := 'n';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '2';
                lattice := 'P';
              end;
        105,
        112,
        131,
        159,
        163,
        186,
        190,
        194,
        218,
        223 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '2';
                lattice := 'P';
              end;
        106,
        135 : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '2';
                lattice := 'P';
              end;
        108,
        120,
        140 : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'I';
              end;
        109,
        122,
        220,
        230 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '4';
                lattice := 'I';
              end;
        110 : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '4';
                lattice := 'I';
              end;
        113 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 2;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        114 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 2;
                hhl := '2';
                lattice := 'P';
              end;
        125 : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
         126 : begin
                glide[ 1 ] := 'n';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '2';
                lattice := 'P';
              end;
        130 : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '2';
                lattice := 'P';
              end;
        133 : begin
                glide[ 1 ] := 'b';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '2';
                lattice := 'P';
              end;
        134 : begin
                glide[ 1 ] := 'n';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        137 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '2';
                lattice := 'P';
              end;
        138 : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
              end;
        141 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '4';
                lattice := 'I';
              end;
        142 : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := '0';
                glide[ 3 ] := 'a';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '4';
                lattice := 'I';
              end;
        144,
        145,
        151,
        152,
        153,
        154,
        171,
        172,
        180,
        181 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 3;
                lattice := 'P';
              end;
        146,
        148,
        155,
        160,
        166 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'R';
              end;
        158,
        165,
        185,
        188,
        193 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
                h_hl := '2';
              end;
        161,
        167 : begin
                glide[ 1 ] := 'c';
                glide[ 2 ] := 'c';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'R';
                h_hl := '2';
              end;
        169,
        170,
        178,
        179 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 6;
                lattice := 'P';
              end;
        184,
        192 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'P';
                hhl := '2';
                h_hl := '2';
              end;
        210 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 4;
                screw[ 2 ] := 4;
                screw[ 3 ] := 4;
                lattice := 'F';
              end;
        212,
        213 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 4;
                screw[ 2 ] := 4;
                screw[ 3 ] := 4;
                lattice := 'P';
              end;
        214 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 4;
                screw[ 2 ] := 4;
                screw[ 3 ] := 4;
                lattice := 'I';
              end;
        219,
        226 : begin
                glide[ 1 ] := '0';
                glide[ 2 ] := '0';
                glide[ 3 ] := '0';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '2';
                lattice := 'F';
              end;
        222 : begin
                glide[ 1 ] := 'n';
                glide[ 2 ] := 'n';
                glide[ 3 ] := 'n';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                hhl := '2';
                lattice := 'P';
              end;
        228 : begin
                glide[ 1 ] := 'd';
                glide[ 2 ] := 'd';
                glide[ 3 ] := 'd';
                screw[ 1 ] := 1;
                screw[ 2 ] := 1;
                screw[ 3 ] := 1;
                lattice := 'F';
                hhl := '2';
              end;
        otherwise
          write_fortran( ili , ' Space group not implemented' );
          if ili = 6 then
            begin
              lib$getjpi( jpi$_master_pid , , , master_pid );
              lib$getjpi( jpi$_terminal , master_pid , , , terminal_name );
              lib$getdvi( dvi$_tt_page , , terminal_name , len_page , , );
              writeln(  ' ' , chr( 27 ) , '[1;' , len_page:2 , 'r' , chr( 27 ) ,
                '[' , len_page:2 , ';1H' );
            end;
          reply_oper9( 'lsqprof: spacegroup not implemented' );
          halt;
        end;
{}
{ Remove extinctions }
      npk := 0;
      for i := 1 to uhdi.npk do
        begin
          extinction := false;
          index[ 1 ] := geind.ih_s[ i ];
          index[ 2 ] := geind.ik_s[ i ];
          index[ 3 ] := geind.il_s[ i ];
          for j := 1 to 3 do
            begin
{}
{ Screw axis }
              if ( ( index[ j mod 3 + 1 ] = 0 ) and ( index[ ( j + 1 ) mod 3 +
                1 ] = 0 ) ) then
                  extinction := ( extinction or ( index[ j ] mod screw[ j ] <>
                    0 ) );
{}
{ Glide planes }
              if ( index[ j ] = 0 ) then
                case glide[ j ] of
                  'a' : extinction := ( extinction or ( index[ 1 ] mod 2 <> 0 )
                          );
                  'b' : extinction := ( extinction or ( index[ 2 ] mod 2 <> 0 )
                          );
                  'c' : extinction := ( extinction or ( index[ 3 ] mod 2 <> 0 )
                          );
                  'n' : extinction := ( extinction or ( ( index[ j mod 3 + 1 ]
                          + index[ ( j + 1 ) mod 3 + 1 ] ) mod 2 <> 0 ) );
                  'd' : extinction := ( extinction or ( ( index[ j mod 3 + 1 ]
                          + index[ ( j + 1 ) mod 3 + 1 ] ) mod 4 <> 0 ) );
                  '0' : ;
                end;
            end;
{}
{ Lattice centering }
          case lattice of
            'A' : extinction := ( extinction or ( ( index[ 2 ] + index[ 3 ] )
                    mod 2 <> 0 ) );
            'B' : extinction := ( extinction or ( ( index[ 1 ] + index[ 3 ] )
                    mod 2 <> 0 ) );
            'C' : extinction := ( extinction or ( ( index[ 2 ] + index[ 1 ] )
                    mod 2 <> 0 ) );
            'R' : extinction := ( extinction or ( ( index[ 2 ] - index[ 1 ] +
                    index[ 3 ] ) mod 3 <> 0 ) );
            'F' : begin
                    extinction := ( extinction or ( ( index[ 2 ] + index[ 3 ] )
                      mod 2 <> 0 ) );
                    extinction := ( extinction or ( ( index[ 1 ] + index[ 3 ] )
                      mod 2 <> 0 ) );
                    extinction := ( extinction or ( ( index[ 2 ] + index[ 1 ] )
                      mod 2 <> 0 ) );
                  end;
            'I' : extinction := ( extinction or ( ( index[ 1 ] + index[ 2 ] +
                    index[ 3 ] ) mod 2 <> 0 ) );
            'P' : ;
          end;
{}
{ hhl extinction }
          if groupno < 195 then
            begin
              if index[ 1 ] = index[ 2 ] then
                case hhl of
                  '2' : extinction := ( extinction or ( index[ 3 ] mod 2 <> 0 )
                          );
                  '4' : extinction := ( extinction or ( ( 2 * index[ 1 ] +
                          index[ 3 ] ) mod 4 <> 0 ) );
                  '0' : ;
                end;
            end
          else
            begin
            if abs( index[ 1 ] ) = abs( index[ 2 ] ) then
              case hhl of
                '2' : extinction := ( extinction or ( index[ 3 ] mod 2 <> 0 ) );
                '4' : extinction := ( extinction or ( ( 2 * index[ 1 ] + index[
                        3 ] ) mod 4 <> 0 ) );
                '0' : ;
              end;
              if abs( index[ 2 ] ) = abs( index[ 3 ] ) then
                case hhl of
                  '2' : extinction := ( extinction or ( index[ 1 ] mod 2 <> 0 )
                          );
                  '4' : extinction := ( extinction or ( ( 2 * index[ 2 ] +
                          index[ 1 ] ) mod 4 <> 0 ) );
                  '0' : ;
                end;
              if abs( index[ 3 ] ) = abs( index[ 1 ] ) then
                case hhl of
                  '2' : extinction := ( extinction or ( index[ 2 ] mod 2 <> 0 )
                          );
                  '4' : extinction := ( extinction or ( ( 2 * index[ 3 ] +
                          index[ 2 ] ) mod 4 <> 0 ) );
                  '0' : ;
                end;
            end;
{}
{ h-hl extinction }
          if index[ 1 ] = -index[ 2 ] then
            case h_hl of
              '2' : extinction := ( extinction or ( index[ 3 ] mod 2 <> 0 ) );
              '0' : ;
            end;
{}
{ Update reflection list }
          if not extinction then
            begin
              npk := npk + 1;
              geind.ih_s[ npk ] := geind.ih_s[ i ];
              geind.ik_s[ npk ] := geind.ik_s[ i ];
              geind.il_s[ npk ] := geind.il_s[ i ];
              geind.theta2_s[ npk ] :=geind.theta2_s[ i ];
            end;
        end;
{}
{ Update number of peaks }
      uhdi.npk := npk;
{}
    end;
end.    
