module partition_hkli;
{}
(******************************************************************************)
(*                                                                            *)
(*             Author : J.Jansen             Date : 23 November 1988          *)
(*                                                                            *)
(*----------------------------------------------------------------------------*)
(*                                                                            *)
(* Procedure to make a partition on 2-theta of the ommon block geind          *)
(*                                                                            *)
(*----------------------------------------------------------------------------*)
(*                                                                            *)
(*     Variable          Type                 Purpose                         *)
(*     start            integer*2     Start of data set                       *)
(*     finish           integer*2     End of data set                         *)
(*     middle_low       integer*2     Lower partition boundary                *)
(*     middle_up        integer*2     Upper partition boundary                *)
(*     pivot            real          Pivot                                   *)
(*     subscr           integer*2     Array subscript of the pivot            *)
(*                                                                            *)
(*----------------------------------------------------------------------------*)
(*                                                                            *)
(*     Calls procedure : swap_hkli                                            *)
(*                                                                            *)
(******************************************************************************)
{}
  type word = [word]-32768..32767;
{}
  [global]procedure partition_hkli( start , finish : word; var middle_up ,
          middle_low : word );
{}
    procedure swap_hkli( index1 , index2 : word ); extern;
{}
    %include 'common_geind_pas.inc/list'
{}
    var
      pivot        : real;
      subscr       : word;
    label
      left,
      swap;
{}
    begin
{}
{ Select pivot }
      subscr := ( start + finish ) div 2;
      pivot := geind.theta2_s[ subscr ];
{}
{ Initialize }
      middle_up := start;
      middle_low := finish;
{}
{ Sort on 2-theta larger or smaller than the pivot }
      while middle_up <= middle_low do
        begin
          for middle_up := middle_up to finish do
            if geind.theta2_s[ middle_up ] > pivot then
              goto left;
          middle_up := finish + 1;
left:
          for middle_low := middle_low downto start do
            if geind.theta2_s[ middle_low ] < pivot then
              goto swap;
          middle_low := start - 1;
swap:
          if middle_up < middle_low then
            begin
              swap_hkli( middle_up , middle_low );
              middle_up := middle_up + 1;
              middle_low := middle_low - 1;
            end;
        end;
{}
{ We make now a split between middle_low and middle_up }
      if middle_up < subscr then
        begin
          swap_hkli( subscr , middle_up );
          middle_up := middle_up + 1;
        end
      else if subscr < middle_low then
        begin
          swap_hkli( subscr , middle_low );
          middle_low := middle_low - 1;
        end;
    end;
end.
